@@ -7,59 +7,77 @@ With lazy-regex macros, regular expressions
 * can hold flags as suffix: `let case_insensitive_regex = regex!("ab*"i);`
 * are defined in a less verbose way
 
-The [regex!] macro returns references to normal instances of [regex::Regex] or [regex::bytes::Regex] so all the usual features are available.
+The [`regex!`] macro returns references to normal instances of [`regex::Regex`] or [`regex::bytes::Regex`] so all the usual features are available.
 
 But most often, you won't even use the `regex!` macro but the other macros which are specialized for testing a match, replacing, or capturing groups in some common situations:
 
-* [Test a match](#test-a-match) with [regex_is_match!]
-* [Extract a value](#extract-a-value) with [regex_find!]
-* [Capture](#capture) with [regex_captures!] and [regex_captures_iter!]
-* [Replace with captured groups](#replace-with-captured-groups) with [regex_replace!] and [regex_replace_all!]
-* [Switch over patterns](#switch-over-patterns) with [regex_switch!]
+* [Test a match](#test-a-match) with [`regex_is_match!`]
+* [Extract a value](#extract-a-value) with [`regex_find!`]
+* [Capture](#capture) with [`regex_captures!`]
+* [Iter on captures](#iter-on-captures) with [`regex_captures_iter!`]
+* [Replace with captured groups](#replace-with-captured-groups) with [`regex_replace!`] and [`regex_replace_all!`]
+* [Switch over patterns](#switch-over-patterns) with [`regex_switch!`]
 
 They support the `B` flag for the `regex::bytes::Regex` variant.
 
-All macros exist with a `bytes_` prefix for building `bytes::Regex`, so you also have [bytes_regex!], [bytes_regex_is_match!], [bytes_regex_find!], [bytes_regex_captures!], [bytes_regex_replace!], [bytes_regex_replace_all!], and [bytes_regex_switch!].
+All macros exist with a `bytes_` prefix for building `bytes::Regex`, so you also have [`bytes_regex!`], [`bytes_regex_is_match!`], [`bytes_regex_find!`], [`bytes_regex_captures!`], [`bytes_regex_replace!`], [`bytes_regex_replace_all!`], and [`bytes_regex_switch!`].
 
 Some structs of the regex crate are reexported to ease dependency managment.
 
 # Build Regexes
 
-```rust
-use lazy_regex::regex;
+Build a simple regex:
 
-// build a simple regex
+```rust
+# use lazy_regex::regex;
 let r = regex!("sa+$");
 assert_eq!(r.is_match("Saa"), false);
+```
 
-// build a regex with flag(s)
+Build a regex with flag(s):
+
+```rust
+# use lazy_regex::regex;
 let r = regex!("sa+$"i);
 assert_eq!(r.is_match("Saa"), true);
+```
+You can use a raw literal:
 
-// you can use a raw literal
+```rust
+# use lazy_regex::regex;
 let r = regex!(r#"^"+$"#);
 assert_eq!(r.is_match("\"\""), true);
+```
 
-// or a raw literal with flag(s)
+Or a raw literal with flag(s):
+```rust
+# use lazy_regex::regex;
 let r = regex!(r#"^\s*("[a-t]*"\s*)+$"#i);
 assert_eq!(r.is_match(r#" "Aristote" "Platon" "#), true);
+```
 
-// build a regex that operates on &[u8]
+Build a regex that operates on `&[u8]`:
+```rust
+# use lazy_regex::regex;
 let r = regex!("(byte)?string$"B);
 assert_eq!(r.is_match(b"bytestring"), true);
+```
 
-// there's no problem using the multiline definition syntax
+There's no problem using the multiline definition syntax:
+```rust
+# use lazy_regex::regex;
 let r = regex!(r"(?x)
     (?P<name>\w+)
     -
     (?P<version>[0-9.]+)
 ");
 assert_eq!(r.find("This is lazy_regex-2.2!").unwrap().as_str(), "lazy_regex-2.2");
-// (look at the regex_captures! macro to easily extract the groups)
-
 ```
+
+(look at the `regex_captures!` macro to easily extract the groups)
+
+This line doesn't compile because the regex is invalid:
 ```compile_fail
-// this line doesn't compile because the regex is invalid:
 let r = regex!("(unclosed");
 
 ```
@@ -85,7 +103,7 @@ let b = bytes_regex_is_match!("[ab]+", b"car");
 assert_eq!(b, true);
 ```
 
-doc: [regex_is_match!]
+See [`regex_is_match!`]
 
 
 # Extract a value
@@ -99,7 +117,7 @@ let f_word = regex_find!(r"\bf\w+\b"B, b"The forest is silent.");
 assert_eq!(f_word, Some(b"forest" as &[u8]));
 ```
 
-doc: [regex_find!]
+See [`regex_find!`]
 
 # Capture
 
@@ -123,11 +141,31 @@ It's checked at compile time to ensure you have the right number of capturing gr
 
 You receive `""` for optional groups with no value.
 
-See [regex_captures!] and [regex_captures_iter!]
+See [`regex_captures!`]
+
+# Iter on captures
+
+```rust
+use lazy_regex::regex_captures_iter;
+
+let hay = "'Citizen Kane' (1941), 'The Wizard of Oz' (1939), 'M' (1931).";
+let mut movies = vec![];
+let iter = regex_captures_iter!(r"'([^']+)'\s+\(([0-9]{4})\)", hay);
+for (_, [title, year]) in iter.map(|c| c.extract()) {
+    movies.push((title, year.parse::<i64>().unwrap()));
+}
+assert_eq!(movies, vec![
+    ("Citizen Kane", 1941),
+    ("The Wizard of Oz", 1939),
+    ("M", 1931),
+]);
+```
+
+See [`regex_captures_iter!`]
 
 # Replace with captured groups
 
-The [regex_replace!] and [regex_replace_all!] macros bring once compilation and compilation time checks to the `replace` and `replace_all` functions.
+The [`regex_replace!`] and [`regex_replace_all!`] macros bring once compilation and compilation time checks to the `replace` and `replace_all` functions.
 
 ## Replace with a closure
 
@@ -157,7 +195,7 @@ assert_eq!(&output, "OwO");
 
 # Switch over patterns
 
-Execute the expression bound to the first matching regex, with named captured groups declared as varibles:
+Execute the expression bound to the first matching regex, with named captured groups declared as variables:
 
 ```rust
 use lazy_regex::regex_switch;
@@ -185,26 +223,26 @@ assert_eq!("scroll-lines(42)".parse(), Ok(ScrollCommand::Lines(42)));
 assert_eq!("scroll-lines(XLII)".parse::<ScrollCommand>(), Err("unknown command"));
 ```
 
-doc: [regex_switch!]
+See [`regex_switch!`]
 
 # Shared lazy static
 
 When a regular expression is used in several functions, you sometimes don't want
 to repeat it but have a shared static instance.
 
-The [regex!] macro, while being backed by a lazy static regex, returns a reference.
+The [`regex!`] macro, while being backed by a lazy static regex, returns a reference.
 
-If you want to have a shared lazy static regex, use the [lazy_regex!] macro:
+If you want to have a shared lazy static regex, use the [`lazy_regex!`] macro:
 
 ```rust
-use lazy_regex::*;
+# use lazy_regex::*;
 
 pub static GLOBAL_REX: Lazy<Regex> = lazy_regex!("^ab+$"i);
 ```
 
 Like for the other macros, the regex is static, checked at compile time, and lazily built at first use.
 
-doc: [lazy_regex!]
+See [`lazy_regex!`]
 
 */
 
